@@ -72,6 +72,7 @@ class ResidualBlock(tf.keras.layers.Layer):
                use_sync_bn=False,
                norm_momentum=0.99,
                norm_epsilon=0.001,
+               bn_trainable=True,
                **kwargs):
     """Initializes a residual block with BN after convolutions.
 
@@ -99,6 +100,8 @@ class ResidualBlock(tf.keras.layers.Layer):
       use_sync_bn: A `bool`. If True, use synchronized batch normalization.
       norm_momentum: A `float` of normalization momentum for the moving average.
       norm_epsilon: A `float` added to variance to avoid dividing by zero.
+      bn_trainable: A `bool` that indicates whether batch norm layers should be
+        trainable. Default to True.
       **kwargs: Additional keyword arguments to be passed.
     """
     super(ResidualBlock, self).__init__(**kwargs)
@@ -126,6 +129,7 @@ class ResidualBlock(tf.keras.layers.Layer):
     else:
       self._bn_axis = 1
     self._activation_fn = tf_utils.get_activation(activation)
+    self._bn_trainable = bn_trainable
 
   def build(self, input_shape):
     if self._use_projection:
@@ -140,7 +144,8 @@ class ResidualBlock(tf.keras.layers.Layer):
       self._norm0 = self._norm(
           axis=self._bn_axis,
           momentum=self._norm_momentum,
-          epsilon=self._norm_epsilon)
+          epsilon=self._norm_epsilon,
+          trainable=self._bn_trainable)
 
     self._conv1 = tf.keras.layers.Conv2D(
         filters=self._filters,
@@ -154,7 +159,8 @@ class ResidualBlock(tf.keras.layers.Layer):
     self._norm1 = self._norm(
         axis=self._bn_axis,
         momentum=self._norm_momentum,
-        epsilon=self._norm_epsilon)
+        epsilon=self._norm_epsilon,
+        trainable=self._bn_trainable)
 
     self._conv2 = tf.keras.layers.Conv2D(
         filters=self._filters,
@@ -168,7 +174,8 @@ class ResidualBlock(tf.keras.layers.Layer):
     self._norm2 = self._norm(
         axis=self._bn_axis,
         momentum=self._norm_momentum,
-        epsilon=self._norm_epsilon)
+        epsilon=self._norm_epsilon,
+        trainable=self._bn_trainable)
 
     if self._se_ratio and self._se_ratio > 0 and self._se_ratio <= 1:
       self._squeeze_excitation = nn_layers.SqueezeExcitation(
@@ -203,7 +210,8 @@ class ResidualBlock(tf.keras.layers.Layer):
         'activation': self._activation,
         'use_sync_bn': self._use_sync_bn,
         'norm_momentum': self._norm_momentum,
-        'norm_epsilon': self._norm_epsilon
+        'norm_epsilon': self._norm_epsilon,
+        'bn_trainable': self._bn_trainable
     }
     base_config = super(ResidualBlock, self).get_config()
     return dict(list(base_config.items()) + list(config.items()))
@@ -249,6 +257,7 @@ class BottleneckBlock(tf.keras.layers.Layer):
                use_sync_bn=False,
                norm_momentum=0.99,
                norm_epsilon=0.001,
+               bn_trainable=True,
                **kwargs):
     """Initializes a standard bottleneck block with BN after convolutions.
 
@@ -277,6 +286,8 @@ class BottleneckBlock(tf.keras.layers.Layer):
       use_sync_bn: A `bool`. If True, use synchronized batch normalization.
       norm_momentum: A `float` of normalization momentum for the moving average.
       norm_epsilon: A `float` added to variance to avoid dividing by zero.
+      bn_trainable: A `bool` that indicates whether batch norm layers should be
+        trainable. Default to True.
       **kwargs: Additional keyword arguments to be passed.
     """
     super(BottleneckBlock, self).__init__(**kwargs)
@@ -303,7 +314,7 @@ class BottleneckBlock(tf.keras.layers.Layer):
       self._bn_axis = -1
     else:
       self._bn_axis = 1
-    self._activation_fn = tf_utils.get_activation(activation)
+    self._bn_trainable = bn_trainable
 
   def build(self, input_shape):
     if self._use_projection:
@@ -331,7 +342,8 @@ class BottleneckBlock(tf.keras.layers.Layer):
       self._norm0 = self._norm(
           axis=self._bn_axis,
           momentum=self._norm_momentum,
-          epsilon=self._norm_epsilon)
+          epsilon=self._norm_epsilon,
+          trainable=self._bn_trainable)
 
     self._conv1 = tf.keras.layers.Conv2D(
         filters=self._filters,
@@ -344,7 +356,10 @@ class BottleneckBlock(tf.keras.layers.Layer):
     self._norm1 = self._norm(
         axis=self._bn_axis,
         momentum=self._norm_momentum,
-        epsilon=self._norm_epsilon)
+        epsilon=self._norm_epsilon,
+        trainable=self._bn_trainable)
+    self._activation1 = tf_utils.get_activation(
+        self._activation, use_keras_layer=True)
 
     self._conv2 = tf.keras.layers.Conv2D(
         filters=self._filters,
@@ -359,7 +374,10 @@ class BottleneckBlock(tf.keras.layers.Layer):
     self._norm2 = self._norm(
         axis=self._bn_axis,
         momentum=self._norm_momentum,
-        epsilon=self._norm_epsilon)
+        epsilon=self._norm_epsilon,
+        trainable=self._bn_trainable)
+    self._activation2 = tf_utils.get_activation(
+        self._activation, use_keras_layer=True)
 
     self._conv3 = tf.keras.layers.Conv2D(
         filters=self._filters * 4,
@@ -372,7 +390,10 @@ class BottleneckBlock(tf.keras.layers.Layer):
     self._norm3 = self._norm(
         axis=self._bn_axis,
         momentum=self._norm_momentum,
-        epsilon=self._norm_epsilon)
+        epsilon=self._norm_epsilon,
+        trainable=self._bn_trainable)
+    self._activation3 = tf_utils.get_activation(
+        self._activation, use_keras_layer=True)
 
     if self._se_ratio and self._se_ratio > 0 and self._se_ratio <= 1:
       self._squeeze_excitation = nn_layers.SqueezeExcitation(
@@ -390,6 +411,7 @@ class BottleneckBlock(tf.keras.layers.Layer):
           self._stochastic_depth_drop_rate)
     else:
       self._stochastic_depth = None
+    self._add = tf.keras.layers.Add()
 
     super(BottleneckBlock, self).build(input_shape)
 
@@ -408,7 +430,8 @@ class BottleneckBlock(tf.keras.layers.Layer):
         'activation': self._activation,
         'use_sync_bn': self._use_sync_bn,
         'norm_momentum': self._norm_momentum,
-        'norm_epsilon': self._norm_epsilon
+        'norm_epsilon': self._norm_epsilon,
+        'bn_trainable': self._bn_trainable
     }
     base_config = super(BottleneckBlock, self).get_config()
     return dict(list(base_config.items()) + list(config.items()))
@@ -425,11 +448,11 @@ class BottleneckBlock(tf.keras.layers.Layer):
 
     x = self._conv1(inputs)
     x = self._norm1(x)
-    x = self._activation_fn(x)
+    x = self._activation1(x)
 
     x = self._conv2(x)
     x = self._norm2(x)
-    x = self._activation_fn(x)
+    x = self._activation2(x)
 
     x = self._conv3(x)
     x = self._norm3(x)
@@ -440,7 +463,8 @@ class BottleneckBlock(tf.keras.layers.Layer):
     if self._stochastic_depth:
       x = self._stochastic_depth(x, training=training)
 
-    return self._activation_fn(x + shortcut)
+    x = self._add([x, shortcut])
+    return self._activation3(x)
 
 
 @tf.keras.utils.register_keras_serializable(package='Vision')
@@ -549,11 +573,8 @@ class InvertedBottleneckBlock(tf.keras.layers.Layer):
       self._bn_axis = -1
     else:
       self._bn_axis = 1
-    self._activation_fn = tf_utils.get_activation(activation)
     if not depthwise_activation:
       self._depthwise_activation = activation
-    self._depthwise_activation_fn = tf_utils.get_activation(
-        self._depthwise_activation)
     if regularize_depthwise:
       self._depthsize_regularizer = kernel_regularizer
     else:
@@ -582,6 +603,8 @@ class InvertedBottleneckBlock(tf.keras.layers.Layer):
           axis=self._bn_axis,
           momentum=self._norm_momentum,
           epsilon=self._norm_epsilon)
+      self._activation_layer = tf_utils.get_activation(
+          self._activation, use_keras_layer=True)
 
     if self._use_depthwise:
       # Depthwise conv.
@@ -599,6 +622,8 @@ class InvertedBottleneckBlock(tf.keras.layers.Layer):
           axis=self._bn_axis,
           momentum=self._norm_momentum,
           epsilon=self._norm_epsilon)
+      self._depthwise_activation_layer = tf_utils.get_activation(
+          self._depthwise_activation, use_keras_layer=True)
 
     # Squeeze and excitation.
     if self._se_ratio and self._se_ratio > 0 and self._se_ratio <= 1:
@@ -639,6 +664,7 @@ class InvertedBottleneckBlock(tf.keras.layers.Layer):
           self._stochastic_depth_drop_rate)
     else:
       self._stochastic_depth = None
+    self._add = tf.keras.layers.Add()
 
     super(InvertedBottleneckBlock, self).build(input_shape)
 
@@ -676,14 +702,14 @@ class InvertedBottleneckBlock(tf.keras.layers.Layer):
     if self._expand_ratio > 1:
       x = self._conv0(inputs)
       x = self._norm0(x)
-      x = self._activation_fn(x)
+      x = self._activation_layer(x)
     else:
       x = inputs
 
     if self._use_depthwise:
       x = self._conv1(x)
       x = self._norm1(x)
-      x = self._depthwise_activation_fn(x)
+      x = self._depthwise_activation_layer(x)
 
     if self._squeeze_excitation:
       x = self._squeeze_excitation(x)
@@ -696,7 +722,7 @@ class InvertedBottleneckBlock(tf.keras.layers.Layer):
         self._strides == 1):
       if self._stochastic_depth:
         x = self._stochastic_depth(x, training=training)
-      x = tf.add(x, shortcut)
+      x = self._add([x, shortcut])
 
     return x
 
