@@ -83,7 +83,9 @@ class StandardTrainer(runner.AbstractTrainer, metaclass=abc.ABCMeta):
   `tf.function`, as determined by the `options` passed to `__init__`.
   """
 
-  def __init__(self, train_dataset, options: StandardTrainerOptions = None):
+  def __init__(self,
+               train_dataset,
+               options: Optional[StandardTrainerOptions] = None):
     """Initializes the `StandardTrainer` instance.
 
     Args:
@@ -215,10 +217,10 @@ class StandardEvaluatorOptions:
 
   Attributes:
     use_tf_function: A boolean indicating whether to apply `tf.function` to the
-      training loop. This will only affect the body of the loop (involving
-      `train_step`); `train_loop_begin` and `train_loop_end` will always be run
+      evaluation loop. This will only affect the body of the loop (involving
+      `eval_step`); `eval_loop_begin` and `eval_loop_end` will always be run
       in eager mode.
-    use_tf_while_loop: A boolean indicating whether to run the training loop
+    use_tf_while_loop: A boolean indicating whether to run the evaluation loop
       using a `tf.while_loop`. If `True`, `use_tf_function` must also be `True`.
     recreate_iterator_for_each_eval: A boolean indicating whether to recreate a
       new iterator for the evaluation dataset before each round of evaluation,
@@ -256,7 +258,9 @@ class StandardEvaluator(runner.AbstractEvaluator, metaclass=abc.ABCMeta):
   is recommended in this case.
   """
 
-  def __init__(self, eval_dataset, options: StandardEvaluatorOptions = None):
+  def __init__(self,
+               eval_dataset,
+               options: Optional[StandardEvaluatorOptions] = None):
     """Initializes the `StandardEvaluator` instance.
 
     Args:
@@ -403,7 +407,7 @@ class StandardEvaluator(runner.AbstractEvaluator, metaclass=abc.ABCMeta):
     pass
 
   def eval_reduce(self,
-                  state: Any = None,
+                  state: Optional[Any] = None,
                   step_outputs: Optional[runner.Output] = None) -> Any:
     """A function to perform per-step reduction on the evaluation outputs.
 
